@@ -13,7 +13,7 @@ import {
   completeSyncSession,
   countSyncSnapshotRecords,
   createSnapshotTable,
-  findSyncSnapshotRecords,
+  findSyncSnapshotRecordsOrderByDependency,
   getModelsForPull,
   getModelsForPush,
   getSyncTicksOfPendingEdits,
@@ -45,6 +45,10 @@ const errorMessageFromSession = session =>
 // after x minutes of no activity, consider a session lapsed and wipe it to avoid holding invalid
 // changes in the database when a sync fails on the facility server end
 
+/**
+ * @typedef {import('../ApplicationContext').ApplicationContext} ApplicationContext
+ */
+
 export class CentralSyncManager {
   static config = _config;
 
@@ -58,6 +62,7 @@ export class CentralSyncManager {
 
   currentSyncTick;
 
+  /** @type {ApplicationContext} */
   store;
 
   purgeInterval;
@@ -165,6 +170,14 @@ export class CentralSyncManager {
     }
   }
 
+  async sessionExists(sessionId) {
+    const session = await this.store.sequelize.models.SyncSession.findOne({
+      where: { id: sessionId },
+    });
+
+    return Boolean(session);
+  }
+
   async connectToSession(sessionId) {
     const session = await this.store.sequelize.models.SyncSession.findOne({
       where: { id: sessionId },
@@ -605,15 +618,18 @@ export class CentralSyncManager {
 
   async getOutgoingChanges(sessionId, { fromId, limit }) {
     const session = await this.connectToSession(sessionId);
-    const snapshotRecords = await findSyncSnapshotRecords(
-      this.store.sequelize,
+    const snapshotRecords = await findSyncSnapshotRecordsOrderByDependency(
+      this.store,
       sessionId,
       SYNC_SESSION_DIRECTION.OUTGOING,
       fromId,
       limit,
     );
-    const { minSourceTick, maxSourceTick } = session.parameters;
-    if (!minSourceTick || !maxSourceTick) {
+    const { minSourceTick, maxSourceTick, isMobile } = session.parameters;
+    
+    // Currently on mobile we don't need to attach changelog to snapshot records
+    // as changelog data is not stored on mobile. We can also skip if the source tick range is not available.
+    if (isMobile || !minSourceTick || !maxSourceTick) {
       return snapshotRecords;
     }
 
